/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is Malte Kraus.
 *
 * Contributor(s):
 *  Malte Kraus <firefox@maltekraus.de> (Original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// don't delay startup:
const STARTUP_MIN_DELAY = 5;

function SyncTimer() {
}
SyncTimer.prototype = {
  get syncEnabled() {
    return this.prefs.getBoolPref("extensions.adblockfilters.sync.enabled");
  },
  get syncTimerEnabled() {
    return this.syncEnabled && this.prefs.getBoolPref("extensions.adblockfilters.sync.useInterval");
  },
  get lastSync() {
    return this.prefs.getIntPref("extensions.adblockfilters.sync.lastSync");
  },
  set lastSync(val) {
    this.prefs.setIntPref("extensions.adblockfilters.sync.lastSync", val);
    this._startSyncTimer();
    return val;
  },
  __syncTimer: null,
  _startSyncTimer: function() {
    if(this.__syncTimer)
      clearTimeout(this.__syncTimer);
    if(!this.syncTimerEnabled && !this.lastSync)
      return;

    var nextSync = nsPreferences.getIntPref("extensions.adblockfilters.sync.interval") + this.lastSync;
    var now = Math.round(new Date().getTime() / 1000);
    if(nextSync + STARTUP_MIN_DELAY < now) {
      nextSync = now + STARTUP_MIN_DELAY;
      LOG("min delay: \n" + nextSync + "\n" + now);
    }
    setTimeout(function(This) { This.startSyncSilent(); }, (nextSync - now) * 1000, this);
  },
  startSyncSilent: function() {
    if(nsPreferences.getIntPref("extensions.adblockfilters.sync.version") == 0) {
      this.initSynchronization();
      return;
    }

    let onNotUploaded = let (This = this) function() { This._onSilentSyncFail() };
    let job = new SyncJob(this.getData(), onNotUploaded);
    let sync = new this.syncService.SyncService(job);
  },
  _onSilentSyncFail: function() {
    // try again in STARTUP_MIN_DELAY:
    setTimeout(function(This) { This.startSyncSilent(); }, STARTUP_MIN_DELAY * 1000, this);
  },
  syncService: {
    setStatusText: function() {}
  }
};

loadScript("sync.js", SyncTimer.prototype.syncService);